#' @keywords internal
#' @importFrom magrittr %>%
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL

#' Fallback doc
#' @param root The path to the root directory of your project.
#' @name fallback_doc
#' @keywords internal
NULL


if (getRversion() >= "2.15.1") {
  utils::globalVariables(c(
    ".",
    NULL
  ))
}

if (FALSE) {
  # {here} is only used as a dependency for default arguments.
  # this is to avoid a false positive CRAN note.
  here::here
}
